[rtems commit] score: Rename _ISR_Flash() into _ISR_Local_flash()

Sebastian Huber sebh at rtems.org
Fri May 20 06:01:33 UTC 2016


Module:    rtems
Branch:    master
Commit:    c2f301b580ebb4a46d657651a814bc9348103546
Changeset: http://git.rtems.org/rtems/commit/?id=c2f301b580ebb4a46d657651a814bc9348103546

Author:    Sebastian Huber <sebastian.huber at embedded-brains.de>
Date:      Wed May 18 08:08:38 2016 +0200

score: Rename _ISR_Flash() into _ISR_Local_flash()

This is a preparation to remove the Giant lock.

Update #2555.

---

 cpukit/rtems/include/rtems/rtems/intr.h     | 2 +-
 cpukit/rtems/src/intrbody.c                 | 2 +-
 cpukit/score/include/rtems/score/isrlevel.h | 2 +-
 cpukit/score/include/rtems/score/isrlock.h  | 4 ++--
 testsuites/tmtests/tm26/task1.c             | 2 +-
 5 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/cpukit/rtems/include/rtems/rtems/intr.h b/cpukit/rtems/include/rtems/rtems/intr.h
index 4142230..7f99d93 100644
--- a/cpukit/rtems/include/rtems/rtems/intr.h
+++ b/cpukit/rtems/include/rtems/rtems/intr.h
@@ -123,7 +123,7 @@ rtems_status_code rtems_interrupt_catch(
  *  available on all configurations.
  */
 #define rtems_interrupt_flash( _isr_cookie ) \
-    _ISR_Flash(_isr_cookie)
+    _ISR_Local_flash(_isr_cookie)
 
 #endif /* RTEMS_SMP */
 
diff --git a/cpukit/rtems/src/intrbody.c b/cpukit/rtems/src/intrbody.c
index abee60d..1fabd4c 100644
--- a/cpukit/rtems/src/intrbody.c
+++ b/cpukit/rtems/src/intrbody.c
@@ -63,7 +63,7 @@ void rtems_interrupt_flash(
   rtems_interrupt_level previous_level
 )
 {
-  _ISR_Flash( previous_level );
+  _ISR_Local_flash( previous_level );
 }
 
 #endif /* RTEMS_SMP */
diff --git a/cpukit/score/include/rtems/score/isrlevel.h b/cpukit/score/include/rtems/score/isrlevel.h
index 0eccd3a..2ad1740 100644
--- a/cpukit/score/include/rtems/score/isrlevel.h
+++ b/cpukit/score/include/rtems/score/isrlevel.h
@@ -97,7 +97,7 @@ typedef uint32_t   ISR_Level;
  *  @param[in] _level The interrupt level previously obtained by
  *  _ISR_Local_disable().
  */
-#define _ISR_Flash( _level ) \
+#define _ISR_Local_flash( _level ) \
   do { \
     RTEMS_COMPILER_MEMORY_BARRIER(); \
     _CPU_ISR_Flash( _level ); \
diff --git a/testsuites/tmtests/tm26/task1.c b/testsuites/tmtests/tm26/task1.c
index 84811b8..69fdc48 100644
--- a/testsuites/tmtests/tm26/task1.c
+++ b/testsuites/tmtests/tm26/task1.c
@@ -552,7 +552,7 @@ void complete_test( void )
   );
 
   put_time(
-    "rtems interrupt: _ISR_Flash",
+    "rtems interrupt: _ISR_Local_flash",
     isr_flash_time,
     1,
     0,



More information about the vc mailing list
diff --git a/cpukit/score/include/rtems/score/isrlock.h b/cpukit/score/include/rtems/score/isrlock.h
index 3843fd6..294adec 100644
--- a/cpukit/score/include/rtems/score/isrlock.h
+++ b/cpukit/score/include/rtems/score/isrlock.h
@@ -303,7 +303,7 @@ typedef struct {
 /**
  * @brief Flashes an ISR lock.
  *
  * On uni-processor configurations this a simple _ISR_Flash().  On SMP
  * configurations this function releases an SMP lock, restores the interrupt
  * status, then disables interrupts and acquires the SMP lock again.
  *
@@ -328,7 +328,7 @@ typedef struct {
     )
 #else
   #define _ISR_lock_Flash( _lock, _context ) \
-    _ISR_Flash( ( _context )->isr_level )
+    _ISR_Local_flash( ( _context )->isr_level )
 #endif
 
 #if defined( RTEMS_PROFILING )
@@ -303,7 +303,7 @@ typedef struct {
  * @brief Flashes an ISR lock.
  *
- * On uni-processor configurations this a simple _ISR_Flash().  On SMP
+ * On uni-processor configurations this a simple _ISR_Local_flash().  On SMP
  * configurations this function releases an SMP lock, restores the interrupt
  * status, then disables interrupts and acquires the SMP lock again.